
#import "ViewController.h"

#import "PGMobileSDK/PGMobileSDK.h"

@interface ViewController ()

@end

@implementation ViewController
{
    //This will hold the response after data is sent to the server.
    NSMutableData *receivedData;
}


@synthesize cardNumberField;
@synthesize expirationField;

@synthesize swipeStatusLabel;
@synthesize requestSwipeButton;
@synthesize activationSwitch;
@synthesize cardReaderType;
@synthesize autodetectSwitch;

@synthesize swipeController;
@synthesize swipedCard;



- (void)viewDidLoad
{
    [super viewDidLoad];
    
    //The Swipe class listens for card reader swipes.
    swipeController = [[PGSwipeController alloc] initWithDelegate:self audioReader:AudioJackReaderUnimag];
    
    //The activation switch appears when a Shuttle reader is detected.
    //Toggling it will activate or deactivate the reader.
    [activationSwitch setOn:FALSE];
    activationSwitch.hidden = TRUE;
    
    //The Request Swipe button begins a swipe request on Shuttle readers,
    //but only if alwaysAcceptSwipe is false.  If alwaysAcceptSwipe is true,
    //swipes do not need to be requested in order to be received.  By default,
    //alwaysAcceptSwipe is true.
    requestSwipeButton.hidden = TRUE;
    //swipeController.uniMagReader.alwaysAcceptSwipe = FALSE;
    
    
    //This will hold the response after data is sent to the server.
    receivedData = nil;
    
    //If a swipe is received, this will hold the swipe data.
    swipedCard = nil;

    [self updateSwipeStatusLabel];
}


- (IBAction)cardReaderTypeValueChanged:(id)sender
{
    //Only one type of audio jack-connected reader can be supported at a time.
    //The interface contains a segmented controller to choose which.
    //The options are 1: Autodetect, 2: Shuttle (UniMag)
    
    [autodetectSwitch setOn:NO animated:YES];
    
    switch (cardReaderType.selectedSegmentIndex)
    {
        case 0:
            [swipeController setAudioJackReaderType:AudioJackReaderIpsEnterprise];
            break;
        case 1:
            [swipeController setAudioJackReaderType:AudioJackReaderUnimag];
            break;
        default:
            break;
    }
    
}

- (IBAction)autodetectSwitchValueChanged:(id)sender {
    // Unselect the current device
    cardReaderType.selectedSegmentIndex = -1;
    
    // Change the type of audio jeck-connected device to autodetect
    [swipeController setAudioJackReaderType:AudioJackReaderAutodetectOnConnect];
}

-(void)deviceAutodetectStarted
{
    swipeStatusLabel.text = @"Detecting card reader...";
}

-(void)deviceAutodetectComplete:(CardReaderAutodetectResult)result
{
    //If the swipe controller is set to autodetect, this event handler will be called
    //when the autodetect completes.
    //In this sample, the segmented control will be updated to show the detected type.
    switch (result)
    {
        case CardReaderAutodetectResultIpsEnterprise:
            cardReaderType.selectedSegmentIndex = 0;
            break;
        case CardReaderAutodetectResultUniMag:
            cardReaderType.selectedSegmentIndex = 1;
            break;
        default:
            cardReaderType.selectedSegmentIndex = -1;
            break;
    }
    
    // Turn off autodetection
    [autodetectSwitch setOn:NO animated:YES];

    //No events were sent to the delegate during autodetect and the device is now ready for use,
    //so the relevant activation, connection, and ready-for-swipe handlers must be called manually.
    PGSwipeDevice *swipeDevice = nil;
    if (result == CardReaderAutodetectResultUniMag) {
        swipeDevice = swipeController.uniMagReader;
    }
    
    if (swipeDevice != nil) {
        [self deviceConnected:swipeDevice];
        [self deviceActivationFinished:swipeDevice result:SwipeActivationResultSuccess];
        if (swipeDevice.isReadyForSwipe) {
            [self deviceBecameReadyForSwipe:swipeDevice];
        }
    } else {
        //The autodetect failed.  Update the status display.
        [self updateSwipeStatusLabel];
    }
}


-(void)deviceConnected:(PGSwipeDevice *)sender
{
    if ([sender isMemberOfClass:[PGSwipeUniMag class]]) {
        activationSwitch.hidden = FALSE;
        [activationSwitch setOn:FALSE];
    }
    [self updateSwipeStatusLabel];
}

-(void)deviceDisconnected:(PGSwipeDevice *)sender
{
    if ([sender isMemberOfClass:[PGSwipeUniMag class]]) {
        activationSwitch.hidden = TRUE;
    }
    [self updateSwipeStatusLabel];
}

-(void)deviceActivationFinished:(PGSwipeDevice *)sender result:(SwipeActivationResult)result
{
    [self updateSwipeStatusLabel];
    
    if (result == SwipeActivationResultSuccess) {
        if ([sender isMemberOfClass:[PGSwipeUniMag class]]) {
            if (!swipeController.uniMagReader.alwaysAcceptSwipe) {
                //Swipes must be requested for the Shuttle if alwaysAcceptSwipe is false.
                //Unhide the button to allow a swipe request.
                requestSwipeButton.hidden = NO;
            }
            [activationSwitch setOn:TRUE];
        }
    } else {
        //Any result other than success has already had an error message
        //displayed by default.  To handle this differently, set the
        //SwipeUniMag.MessageOptions.volumeTooLowMessage or .cardReaderTimeoutMessage
        //to your own message, or set them to nil to suppress display and
        //handle the error here.
    }
}

-(void)deviceDeactivated:(PGSwipeDevice *)sender
{
    [self updateSwipeStatusLabel];
    
    if ([sender isMemberOfClass:[PGSwipeUniMag class]]) {
        requestSwipeButton.hidden = YES;
        [activationSwitch setOn:FALSE];
    }
}

-(void)deviceBecameReadyForSwipe:(PGSwipeDevice *)sender
{
    [self updateSwipeStatusLabel];
    
}

-(void)deviceBecameUnreadyForSwipe:(PGSwipeDevice *)sender reason:(SwipeReasonUnreadyForSwipe)reason;
{
    [self updateSwipeStatusLabel];
    
    //If you use this event to re-request a swipe, make sure to check the reason
    //parameter to make sure the device isn't disconnecting, for example:
    //if (reason != SwipeReasonUnreadyForSwipeDisconnected) {
    //    [swipeController.uniMagReader requestSwipe];
    //}
}

-(void)didSwipeCard:(PGSwipedCard *)card device:(PGSwipeDevice *)sender
{
    if (card != nil) {
        
        swipedCard = [card retain];
        
        cardNumberField.text = card.maskedCardNumber;
        expirationField.text = card.expirationDate;
        
        
    } else {
        
        //A nil card means that there was a swipe but it was unsuccessful.
        
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Swipe Error"
                                                        message:@"The reader was not able to read the card. Please Try Again."
                                                       delegate:nil
                                              cancelButtonTitle:@"OK"
                                              otherButtonTitles:nil];
        
        [alert show];
        [alert release];
    }
    
}

-(void)updateSwipeStatusLabel
{
    //This function updates a label showing whether each type of device is
    // connected / activated / ready to accept a swipe.
    
    NSMutableString *status = [[NSMutableString alloc] init];
    
    NSString *iDynamoConnected = @"Connected";
    NSString *iDynamoActive = @"Active";
    NSString *iDynamoReadyForSwipe = @"Ready";
    if (![swipeController.iDynamoReader isConnected]) {
        iDynamoConnected = @"Disconnected";
    }
    if (![swipeController.iDynamoReader isActivated]) {
        iDynamoActive = @"Inactive";
    }
    if (![swipeController.iDynamoReader isReadyForSwipe]) {
        iDynamoReadyForSwipe = @"Unready";
    }
    [status appendFormat:@"iDynamo: %@ %@ %@\n", iDynamoConnected, iDynamoActive, iDynamoReadyForSwipe];

    
    NSString *magtakConnected = @"Connected";
    NSString *magtakActive = @"Active";
    NSString *magtakReadyForSwipe = @"Ready";
    if (![swipeController.ipsEnterpriseReader isConnected]) {
        magtakConnected = @"Disconnected";
    }
    if (![swipeController.ipsEnterpriseReader isActivated]) {
        magtakActive = @"Inactive";
    }
    if (![swipeController.ipsEnterpriseReader isReadyForSwipe]) {
        magtakReadyForSwipe = @"Unready";
    }
    [status appendFormat:@"IPS Enterprise: %@ %@ %@\n", magtakConnected, magtakActive, magtakReadyForSwipe];

    NSString *uniMagConnected = @"Connected";
    NSString *uniMagActive = @"Active";
    NSString *uniMagReadyForSwipe = @"Ready";
    if (![swipeController.uniMagReader isConnected]) {
        uniMagConnected = @"Disconnected";
    }
    if (![swipeController.uniMagReader isActivated]) {
        uniMagActive = @"Inactive";
    }
    if (![swipeController.uniMagReader isReadyForSwipe]) {
        uniMagReadyForSwipe = @"Unready";
    }
    [status appendFormat:@"uniMag: %@ %@ %@\n", uniMagConnected, uniMagActive, uniMagReadyForSwipe];
    
    [status release];
}



- (IBAction)didClickRequestSwipeButton:(id)sender
{
    if (swipeController.uniMagReader.isActivated
        && !swipeController.uniMagReader.alwaysAcceptSwipe) {
        
        [swipeController.uniMagReader requestSwipe];
    }
}

- (IBAction)activationSwitchValueChanged:(id)sender;
{
    //For Shuttle devices, the activationSwitch controls whether the device
    //is powered up or not.
    
    if (swipeController.uniMagReader.isConnected) {
        if (swipeController.uniMagReader.isActivated && activationSwitch.isOn == FALSE) {
            [swipeController.uniMagReader powerDown];
        } else if (!swipeController.uniMagReader.isActivated && activationSwitch.isOn == TRUE){
            [swipeController.uniMagReader powerUpDevice:YES];
        }
    }
}




-(IBAction)didClickSubmit:(id)sender
{
    
    if (swipedCard != nil) {
        
        [self sendTransactionWithCard:swipedCard];
        
    }
}

- (bool)sendTransactionWithCard:(PGCard *)card
{
    //This sends a simple sale for $1.00.
    //The DirectPost API allows far more flexibility than this brief example
    //demonstrates.  See the DirectPost documentation for more details.
    
    //You will need to change these to your own merchant credentials.
    NSString *gatewayUsername = @"mobiledemo";
    NSString *gatewayPassword = @"password123";
    
    NSString *amountToCharge = @"1.00";
    
    NSString *cardData = [card getDirectPostStringWithCVVIncluded:YES];

    NSString *postText = [NSString stringWithFormat:
                          @"username=%@"
                          "&password=%@"
                          "&type=sale"
                          "&amount=%@"
                          "&%@", //Card data
                          gatewayUsername,
                          gatewayPassword,
                          amountToCharge,
                          cardData];
    
    
    NSData *postData = [postText dataUsingEncoding:NSASCIIStringEncoding allowLossyConversion:YES];
    NSString *postLength = [NSString stringWithFormat:@"%d", (int)[postData length]];
   
    //Depending on your intended usage, this URL should be set to either your
    //own server's transaction processing script or the Payment Gateway's Direct Post URL.
    NSString *serverUrl = @"https://secure.safewebservices.com/api/transact.php";
    NSURL *url = [NSURL URLWithString:serverUrl];

    NSMutableURLRequest *request = [[[NSMutableURLRequest alloc] init] autorelease];
    [request setURL:url];
    [request setHTTPMethod:@"POST"];
    [request setValue:postLength forHTTPHeaderField:@"Content-Length"];
    [request setValue:@"application/x-www-form-urlencoded" forHTTPHeaderField:@"Content-Type"];
    [request setHTTPBody:postData];
    
    
    
    NSURLConnection *connection=[[NSURLConnection alloc] initWithRequest:request delegate:self startImmediately:YES];
    
    if (connection) {
        receivedData=[[NSMutableData data] retain];
        return YES;
    } else {
        return NO;
    }
}

- (void)connection:(NSURLConnection *)connection didReceiveData:(NSData *)data
{
    // append the new data to the receivedData
    [receivedData appendData:data];
}

- (void)connectionDidFinishLoading:(NSURLConnection *)connection
{
    NSString *str = [[NSString alloc] initWithBytes:[receivedData bytes] length:[receivedData length] encoding:NSASCIIStringEncoding];
    
    UIAlertView *alert = [[UIAlertView alloc]
                          initWithTitle:@"Response"
                          message:str
                          delegate:nil
                          cancelButtonTitle:@"Ok"
                          otherButtonTitles:nil];
    [alert show];
    [alert release];
    
    [str release];
    
    [connection release];
    [receivedData release];
}

- (void)connection:(NSURLConnection *)connection
  didFailWithError:(NSError *)error
{
    
    UIAlertView *alert = [[UIAlertView alloc]
                          initWithTitle:@"Connection failed"
                          message:error.description
                          delegate:nil
                          cancelButtonTitle:@"Ok"
                          otherButtonTitles:nil];
    [alert show];
    [alert release];
    
    [connection release];
    [receivedData release];
    
}

-(NSCachedURLResponse *)connection:(NSURLConnection *)connection willCacheResponse:(NSCachedURLResponse *)cachedResponse
{
    //Do not cache responses.
    return nil;
}




-(void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

-(void)dealloc
{
    [swipedCard release];
    [swipeController release];
    [autodetectSwitch release];
    [super dealloc];
}

@end
