package com.paymentgateway.swipeexample;

import com.SafeWebServices.PaymentGateway.*;
import com.SafeWebServices.PaymentGateway.PGSwipeController.SwipeListener;

import android.os.Bundle;
import android.os.Handler;
import android.app.Activity;
import android.view.Menu;
import android.view.View;
import android.widget.EditText;
import android.widget.TextView;

public class MainActivity extends Activity implements SwipeListener {
    
    PGSwipeController swipeController;
    PGSwipedCard card;
    
    private int mInterval = 900000;
    private Handler mHandler;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        
        /*
         * Create swipe controller for device to be used.
         * The device type being used should be un-commented here.
         */
        //this.swipeController = new PGSwipeController(this, PGSwipeDevice.SwipeDevice.UNIMAG);
        this.swipeController = new PGSwipeController(this, PGSwipeDevice.SwipeDevice.ENTERPRISE);
        //this.swipeController = new PGSwipeController(this, PGSwipeDevice.SwipeDevice.IPS);
        /*
         * The default values can be changed here.
         * 
         * For example:
         * this.swipeController.getDevice().setSwipeTimeout(30);
         * this.swipeController.getDevice().setAlwaysAcceptSwipe(false);
         * this.swipeController.getDevice().setActivateReaderOnConnect(false);
         */
        
        // Set keep alive interval
        mHandler = new Handler();
        mKeepAlive.run();
    }
    
    Runnable mKeepAlive = new Runnable() {
        @Override
        public void run() {
            keepAlive();
            mHandler.postDelayed(mKeepAlive, mInterval);
        }
    };
    
    public void keepAlive() {
        this.swipeController.getDevice().requestSwipe();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.activity_main, menu);
        return true;
    }
    /**
     * Creates a transaction and sends it to the gateway.
     * @param v
     */
    public void onClickSend(View v) {
        //Create direct post string
        String transInfo = "username=mobiledemo&password=test1234&type=sale&amount=5.00&" + this.card.getDirectPostString(false);
        //
        //Send transaction information to the gateway(Not part of the SDK)
        SendToGateway send = new SendToGateway(transInfo, this.getCurrentFocus());
        Thread thread = new Thread(send);
        thread.start();
    }
    /**
     * Stops the swipe controller.
     * @param v
     */
    public void onClickStop(View v) {
        this.swipeController.getDevice().stopSwipeController();
    }
    /**
     * Pauses the swipe device so it not read any card swipes.
     * @param v
     */
    public void onClickPause(View v) {
        this.swipeController.getDevice().cancelSwipeRequest();
    }
    /**
     * Resumes the swipe device whether it is paused or stopped.
     * @param v
     */
    public void onClickResume(View v) {
        swipeController.getDevice().requestSwipe();
    }
    
    /*
     * Functions to modify the view and display swiper related information for testing
     */
    public String getText(boolean status) {
        if (status) {
            return "TRUE";
        } else {
            return "FALSE";
        }
    }
    public void updateMsgView(String text) {
        TextView msg = (TextView)findViewById(R.id.textMsg);
        msg.setText(text);
    }
    public void updateSwipeStatus(boolean status) {
        TextView swipe = (TextView)findViewById(R.id.textSwipe);
        swipe.setText(getText(status));
    }
    public void updateActiveStatus(boolean status) {
        TextView active = (TextView)findViewById(R.id.textActive);
        active.setText(getText(status));
    }
    public void updateConnectedStatus(boolean status) {
        TextView conn = (TextView)findViewById(R.id.textConnected);
        conn.setText(getText(status));
    }
    public void updateCardView(String text) {
        EditText ccnum = (EditText)findViewById(R.id.ccnumber);
        ccnum.setText(text);
    }
    public void updateExpView(String text) {
        EditText ccexp = (EditText)findViewById(R.id.ccexp);
        ccexp.setText(text);
    }
    /*
     * Functions called by the swipe device.(non-Javadoc)
     * @see com.SafeWebServices.PaymentGateway.SwipeController.SwipeListener#onSwipedCard(com.SafeWebServices.PaymentGateway.PaymentGatewayCard, com.SafeWebServices.PaymentGateway.SwipeDevice)
     */
    /**
     * Handles a card swipe event.
     */
    @Override
    public void onSwipedCard(final PGSwipedCard card, final PGSwipeDevice swiper) {
        this.card = card;
        //allows event to modify the view
        this.runOnUiThread(new Runnable() {
            public void run() {
                if (card != null) {
                    updateCardView(card.getMaskedCardNumber());
                    updateExpView(card.getExpirationDate());
                    updateMsgView(swiper.getDefaultMsg());
                    updateSwipeStatus(swiper.getIsReadyForSwipe());
                    updateActiveStatus(swiper.getIsActivated());
                    updateConnectedStatus(swiper.getIsConnected());
                } else {
                    updateCardView("NULL");
                }
            }
        });
    }
    /**
     * Is called when the swipe device is ready to accept a card swipe.
     */
    @Override
    public void onDeviceReadyForSwipe(final PGSwipeDevice swiper) {
        this.runOnUiThread(new Runnable() {
            public void run() {
                updateMsgView(swiper.getDefaultMsg());
                updateSwipeStatus(swiper.getIsReadyForSwipe());
            }
        });
    }
    /**
     * Is called when the swipe device is no longer ready to accept a card swipe.
     */
    @Override
    public void onDeviceUnreadyForSwipe(final PGSwipeDevice swiper, PGSwipeDevice.ReasonUnreadyForSwipe reason) {
        this.runOnUiThread(new Runnable() {
            public void run() {
                updateMsgView(swiper.getDefaultMsg());
                updateSwipeStatus(swiper.getIsReadyForSwipe());
            }
        });
    }
    /**
     * Is called when the swipe device is connected to the android device.
     */
    @Override
    public void onDeviceConnected(final PGSwipeDevice swiper) {
        this.runOnUiThread(new Runnable() {
            public void run() {
                updateMsgView(swiper.getDefaultMsg());
                updateSwipeStatus(swiper.getIsReadyForSwipe());
                updateActiveStatus(swiper.getIsActivated());
                updateConnectedStatus(swiper.getIsConnected());
            }
        });
    }
    /**
     * Is called when the swipe device is unplugged from the android device.
     */
    @Override
    public void onDeviceDisconnected(final PGSwipeDevice swiper) {
        this.runOnUiThread(new Runnable() {
            public void run() {
                updateMsgView(swiper.getDefaultMsg());
                updateSwipeStatus(swiper.getIsReadyForSwipe());
                updateActiveStatus(swiper.getIsActivated());
                updateConnectedStatus(swiper.getIsConnected());
            }
        });
    }
    /**
     * Is called when the swipe device is activated.
     * At this point, a swipe can be requested.
     */
    @Override
    public void onDeviceActivationFinished(final PGSwipeDevice swiper) {
        /*
         * If always accept swipe is set to false.
         */
        if (!swiper.getIsReadyForSwipe()) {
            swiper.requestSwipe();
        }
        this.runOnUiThread(new Runnable() {
            public void run() {
                updateMsgView(swiper.getDefaultMsg());
                updateSwipeStatus(swiper.getIsReadyForSwipe());
                updateActiveStatus(swiper.getIsActivated());
                updateConnectedStatus(swiper.getIsConnected());
            }
        });
    }
    /**
     * Called when a swipe can no longer be requested.
     */
    @Override
    public void onDeviceDeactivated(final PGSwipeDevice swiper) {
        this.runOnUiThread(new Runnable() {
            public void run() {
                updateMsgView(swiper.getDefaultMsg());
                updateSwipeStatus(swiper.getIsReadyForSwipe());
                updateActiveStatus(swiper.getIsActivated());
                updateConnectedStatus(swiper.getIsConnected());
            }
        });
    }
}
